var MongoClient = require('mongodb').MongoClient;
var assert = require('assert');
var url = 'mongodb://localhost:27017/test';

exports.connexionMongo = function(callback) {
	MongoClient.connect(url, function(err, db) {
		assert.equal(null, err);
		callback(err, db);
	});
}

exports.countRestaurants = function(db, callback) {
	db.collection('restaurants').count(function(err, res) {
		assert.equal(err, null);
		callback(res);
	});
};

exports.findRestaurants = function(query, fields, filter, db, callback) {
    var cursor = db.collection('restaurants').find(query, fields, filter);
	var res = [];
    cursor.each(function(err, doc) {
		assert.equal(err, null);
		if(doc !== null) {
			res.push(doc);
		} else {
			callback(res);
		}
	});
};

exports.insertRestaurant = function(params, db, callback) {
	var obj = {
		"address" : {
			"coord" : [ -73.9557413, 40.7720266 ]
		},
		"grades" : [
			{
				"date" : new Date("2014-10-01T00:00:00Z"),
				"grade" : "A",
				"score" : 11
			},
			{
				"date" : new Date("2014-01-16T00:00:00Z"),
				"grade" : "B",
				"score" : 17
			}
		]
		};

	var restaurant = Object.assign(obj, params);

    db.collection('restaurants').insertOne(restaurant, function(err, res) {
		assert.equal(err, null);
		callback();
	});
};

exports.updateRestaurant = function(params, db, callback) {
	var id = params.restaurant_id;
	delete params.restaurant_id;
	
	db.collection('restaurants').updateOne(
		{ "restaurant_id" : id },
		{$set: params }, function(err, res) {
			assert.equal(err, null);
			callback();
		}
	);
};

exports.removeRestaurants = function(db, id, callback) {
	db.collection('restaurants').deleteOne(
		{ "restaurant_id": id }, function(err, res) {
			assert.equal(err, null);
			callback();
		}
	);
};