var express = require('express');
var app = express();
var multer = require('multer');
var multerData = multer();

var mongoDBModule = require('./app_modules/crud-mongo');

app.use(express.static('public'));

app.get('/', function(req, res) {
	res.sendFile(__dirname + "/" + "index.html");
})

app.get('/restaurant.html', function(req, res) {
	res.sendFile(__dirname + "/" + "restaurant.html");
})

app.get('/view_restaurant.html/:id', function(req, res) {
	res.sendFile(__dirname + "/" + "view_restaurant.html");
})

app.get('/api/connect', function(req, res) {
	mongoDBModule.connexionMongo(function(err, db) {
		db.close();

		response = {
			message: "Connexion au serveur réussie !"
		};

		res.end(JSON.stringify(response));
	});
})

app.get('/api/countRestaurants', function(req, res) {
	mongoDBModule.connexionMongo(function(err, db) {
		mongoDBModule.countRestaurants(db, function(datas) {
			response = {
				data: datas
			};
			
			res.end(JSON.stringify(response));
			db.close();
		});
	});
})

app.get('/api/getRestaurants/:p', function(req, res) {
	var NUMBER_OF_ITEMS = 10;
	var PAGE_NUMBER = req.params.p;
	
	mongoDBModule.connexionMongo(function(err, db) {
		mongoDBModule.findRestaurants({}, {"restaurant_id": 1, "name": 1, "cuisine": 1, "borough": 1}, { skip: (NUMBER_OF_ITEMS * (PAGE_NUMBER - 1)), limit: NUMBER_OF_ITEMS }, db, function(datas) {
			response = {
				data: datas
			};
			
			res.end(JSON.stringify(response));
			db.close();
		});
	});
})

app.get('/api/getRestaurant/:id/:v?', function(req, res) {
	var fields = {}
	
	if(!req.params.v) {
		fields = {
					"restaurant_id": 1, 
					"name": 1, 
					"cuisine": 1, 
					"borough": 1,
					"address.building": 1,
					"address.street": 1,
					"address.zipcode": 1,
				};
	}

	mongoDBModule.connexionMongo(function(err, db) {
		mongoDBModule.findRestaurants({"restaurant_id": req.params.id}, fields, {}, db, function(datas) {
			response = {
				data: datas
			};
			
			res.end(JSON.stringify(response));
			db.close();
		});
	});
})

app.post('/api/addRestaurant', multerData.fields([]), function(req, res) {
	mongoDBModule.connexionMongo(function(err, db) {
		mongoDBModule.insertRestaurant(req.body, db, function() {
			response = {
				redirect: "/?msg=ajout"
			};
			
			res.end(JSON.stringify(response));
			db.close();
		});
	});
})

app.put('/api/updRestaurant', multerData.fields([]), function(req, res) {
	mongoDBModule.connexionMongo(function(err, db) {
		mongoDBModule.updateRestaurant(req.body, db, function() {
			response = {
				redirect: "/?msg=modification"
			};
			
			res.end(JSON.stringify(response));
			db.close();
		});
	});
})

app.delete('/api/delRestaurant/:id', function(req, res) {
	if(req.params.id != '') {
		mongoDBModule.connexionMongo(function(err, db) {
			mongoDBModule.removeRestaurants(db, req.params.id, function() {
				response = {
					message: "Suppression réussie !"
				};

				res.end(JSON.stringify(response));
				db.close();
			});
		});
	}
})

var server = app.listen(8081, function() {
	var host = server.address().address
	var port = server.address().port

	console.log("Example app listening at http://%s:%s", host, port)
});